SystemOrganization addCategory: #MemoryMonitor!

Morph subclass: #MMGraph
	instanceVariableNames: 'probes tooltip toolTipPosition'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MMGraph methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 20:12'!
addProbe: probe
	probes add: probe! !

!MMGraph methodsFor: 'updating' stamp: 'Alexandre Bergel 5/25/2010 18:27'!
clear
	probes do: #clear! !

!MMGraph methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 5/25/2010 15:08'!
colorForBackground
	^ Color gray! !

!MMGraph methodsFor: 'drawing' stamp: 'Alexandre Bergel 5/25/2010 18:30'!
drawOn: aCanvas
	aCanvas fillRectangle: self bounds color: self colorForBackground.
	probes do: [ :probe | probe renderOnCanvas: aCanvas bounds: self bounds ]! !

!MMGraph methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 6/7/2010 09:07'!
getToolTipTextFor: position
	| str index indexX indexY |
	indexX := (position x * probes first values size / self bounds width) asInteger .
	indexY := (position y * probes first values size / self bounds height) asInteger .
	str := WriteStream on: String new.
	probes do: [:p | 
		indexX > 0 ifTrue: [p writeToolTipTextOn: str forIndex: indexX].
		str cr ].
	^ str contents ! !

!MMGraph methodsFor: 'stepping and presenter' stamp: 'Alexandre Bergel 6/4/2010 20:05'!
handlesMouseEnter: event
	^ true! !

!MMGraph methodsFor: 'accessing' stamp: 'Alexandre Bergel 6/4/2010 20:07'!
handlesMouseOver: event

	^ true! !

!MMGraph methodsFor: 'drawing - morphic' stamp: 'Alexandre Bergel 6/4/2010 20:33'!
highlight: currentPosition 
	probes do: [:p| p highlight: currentPosition ]! !

!MMGraph methodsFor: 'initialization' stamp: 'Alexandre Bergel 6/4/2010 20:26'!
initialize
	super initialize.
	probes := OrderedCollection new.
	toolTipPosition := 0@0! !

!MMGraph methodsFor: 'drawing - morphic' stamp: 'Alexandre Bergel 6/4/2010 20:07'!
mouseEnter: event
	self showToolTip ! !

!MMGraph methodsFor: 'drawing - morphic' stamp: 'Alexandre Bergel 6/4/2010 20:41'!
mouseLeave: event
	tooltip := nil.
	self highlight: nil! !

!MMGraph methodsFor: 'drawing - morphic' stamp: 'Alexandre Bergel 6/4/2010 20:02'!
mouseOver: anEvent
	| currentPosition |
! !

!MMGraph methodsFor: 'accessing-readonly' stamp: 'Alexandre Bergel 5/25/2010 20:25'!
numberOfProbes
	^ probes size! !

!MMGraph methodsFor: 'drawing - morphic' stamp: 'Alexandre Bergel 6/7/2010 09:07'!
showToolTip
	| currentPosition |

	currentPosition := World activeHand position - self bounds origin.

	toolTipPosition := currentPosition.
	tooltip := (UITheme builder newBalloonHelp: (self getToolTipTextFor: currentPosition) for: World activeHand)
		popUpFor: (Morph new) hand:  World activeHand.

	self highlight: currentPosition.
! !

!MMGraph methodsFor: 'stepping and presenter' stamp: 'Alexandre Bergel 6/4/2010 20:03'!
step
	self changed.
	probes do: [:probe | probe updateValue ].
	tooltip ifNotNil: [ 
		tooltip delete.
		self showToolTip ]! !

!MMGraph methodsFor: 'testing' stamp: 'Alexandre Bergel 5/25/2010 15:08'!
stepTime
	"Answer the desired time between steps in milliseconds."

	^ 500! !

StringMorph subclass: #MMMemoryBoundsIndicadorMorph
	instanceVariableNames: 'memoryProbe'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MMMemoryBoundsIndicadorMorph methodsFor: 'initialization' stamp: 'Alexandre Bergel 5/31/2010 22:55'!
initialize 
	super initialize.
	memoryProbe := MUsedMemoryProbe new! !

!MMMemoryBoundsIndicadorMorph methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/31/2010 22:55'!
memoryProbe
	^ memoryProbe! !

!MMMemoryBoundsIndicadorMorph methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/31/2010 22:55'!
memoryProbe: anObject
	memoryProbe := anObject! !

!MMMemoryBoundsIndicadorMorph methodsFor: 'stepping and presenter' stamp: 'AlexandreBergel 12/28/2010 23:22'!
step
	| min max |
	min := ((memoryProbe computeMinValue / (1024 * 1024)) asFloat * 100) asInteger / 100.0.
	max := ((memoryProbe computeMaxValue / (1024 * 1024)) asFloat * 100) asInteger / 100.0.
	self contents: 'Memory min: ', min printString , 'M max: ', max printString, 'M'! !

!MMMemoryBoundsIndicadorMorph methodsFor: 'testing' stamp: 'Alexandre Bergel 5/31/2010 22:55'!
stepTime
	"Update every 5 seconds to avoid hogging the system."
	^ 5000! !

StringMorph subclass: #MMMemoryUsageIndicatorMorph
	instanceVariableNames: 'prevUsage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

Object subclass: #ActivityMonitor
	instanceVariableNames: 'graph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!ActivityMonitor methodsFor: 'initialization' stamp: 'Alexandre Bergel 6/28/2010 00:16'!
initialize
	super initialize.
	
	graph := MMGraph new.
	! !

!ActivityMonitor methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/28/2010 00:30'!
initializeButtonsIn: aWindow! !

!ActivityMonitor methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/28/2010 00:29'!
windowTitle
	^ 'Activity Monitor'! !

ActivityMonitor subclass: #MemoryMonitor
	instanceVariableNames: 'memoryProbe'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

MemoryMonitor class
	instanceVariableNames: 'icon'!

!MemoryMonitor commentStamp: '<historical>' prior: 0!
Manuia means "To your health!!" in Rapanui,  polynesian language used in Easter Island!

MemoryMonitor class
	instanceVariableNames: 'icon'!

!MemoryMonitor class methodsFor: 'icon' stamp: 'AlexandreBergel 11/18/2010 10:44'!
icon
	icon ifNotNil: [ ^ icon ].
	icon := ((ColorForm
	extent: 16@16
	depth: 8
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 1381120 0 0 0 1511936 0 0 7 135271936 0 0 1557 252187395 0 33816576 136453 369168135 2 370414348 68290816 234883851 15 167773196 386072576 100665103 1811 0 0 787 4870 0 0 22 17501952 0 0 17 102040064 0 0 13 302579712 0 0 11 369098752 0 0 0 0 0 0)
	offset: 0@0)
	colorsFromArray: #(#(0.0 0.0 0.0) #(0.0 0.031 0.008) #(0.0 0.07 0.023) #(0.0 0.094 0.031) #(0.0 0.129 0.043000000000000003) #(0.0 0.164 0.059000000000000004) #(0.0 0.176 0.063) #(0.0 0.20700000000000002 0.074) #(0.0 0.231 0.082) #(0.0 0.28500000000000003 0.10200000000000001) #(0.0 0.328 0.121) #(0.0 0.337 0.125) #(0.0 0.34900000000000003 0.125) #(0.0 0.396 0.145) #(0.0 0.435 0.16) #(0.0 0.455 0.164) #(0.0 0.486 0.18) #(0.0 0.517 0.192) #(0.0 0.544 0.199) #(0.0 0.5760000000000001 0.211) #(0.0 0.591 0.219) #(0.0 0.607 0.223) #(0.0 0.634 0.23500000000000001) #(0.0 0.667 0.246) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( ) #( )  )).
	^ icon! !

!MemoryMonitor class methodsFor: 'opening' stamp: 'Alexandre Bergel 6/19/2010 19:05'!
menuCommandOn: aBuilder
	<worldMenu>
	(aBuilder item: #'MemoryMonitor')
		parent: #Tools;
		action: [ self open ];
		icon: self icon.! !

!MemoryMonitor class methodsFor: 'opening' stamp: 'Alexandre Bergel 5/26/2010 19:42'!
open
	^ self new open! !

!MemoryMonitor methodsFor: 'ui' stamp: 'AlexandreBergel 5/16/2011 09:47'!
addProbe
	| className newProbe colors |
	className := UIManager default request: 'Enter the name of a class'.
	className ifNil: [ ^ self ].
	(Smalltalk globals includesKey: className asSymbol) ifFalse: [ self inform: 'class not found'. ^ self ].
	
	newProbe := MInstancesProbe forClassNamed: className asSymbol.

	colors := Color new wheel: 10.
	newProbe color: (colors at: graph numberOfProbes).
	
	graph addProbe: newProbe.! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 20:03'!
buttonAddProbeLabel
	^ 'probe class'! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 17:23'!
buttonClearLabel
	^ 'clear'! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 17:39'!
buttonGarbageCollectLabel
	^ 'gc'! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 17:40'!
buttonOn
	^ false! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 17:24'!
clear
	graph clear! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 17:39'!
garbageCollect
	Smalltalk garbageCollect! !

!MemoryMonitor methodsFor: 'initialize-release' stamp: 'Alexandre Bergel 6/28/2010 00:16'!
initialize
	super initialize.

	graph 
		addProbe: (memoryProbe := MUsedMemoryProbe new); 
		addProbe: MMGCProbe new;
		addProbe: MEndOfMemoryProbe new! !

!MemoryMonitor methodsFor: 'ui' stamp: 'Alexandre Bergel 5/25/2010 20:15'!
initializeButtonsIn: aWindow

	| clearButton garbageCollectButton addProbeButton |
	clearButton := PluggableButtonMorph
				on: self
				getState: #buttonOn
				action: #clear
				label: #buttonClearLabel.
	aWindow 
		addMorph: clearButton
		fullFrame: (LayoutFrame fractions: (0 @ 0 corner: 0.3 @ 0) offsets: (0 @ 0 corner: 0 @ 24)).

	garbageCollectButton := PluggableButtonMorph
				on: self
				getState: #buttonOn
				action: #garbageCollect
				label: #buttonGarbageCollectLabel.
	aWindow 
		addMorph: garbageCollectButton
		fullFrame: (LayoutFrame fractions: (0.3 @ 0 corner: 0.6 @ 0) offsets: (0 @ 0 corner: 0 @ 24)).

	addProbeButton := PluggableButtonMorph
				on: self
				getState: #buttonOn
				action: #addProbe
				label: #buttonAddProbeLabel.
	aWindow 
		addMorph: addProbeButton
		fullFrame: (LayoutFrame fractions: (0.6 @ 0 corner: 1 @ 0) offsets: (0 @ 0 corner: 0 @ 24)).
! !

!MemoryMonitor methodsFor: 'public' stamp: 'PhilippeBack 2/24/2013 18:06'!
open
	"
	self new open
	"
	| window stringMorph |
	window := StandardWindow  labelled: self windowTitle.

	window 
		addMorph: graph
		fullFrame: (LayoutFrame fractions: (0 @ 0 corner: 1 @ 0.6) offsets: (0 @ 24 corner: 0 @ 0)).

	window 
		addMorph: (stringMorph := MMMemoryUsageIndicatorMorph new)
		fullFrame: (LayoutFrame fractions: (0 @ 0.6 corner: 1 @ 0.8) offsets: (0 @ 0 corner: 0 @ 0)).

	stringMorph := MMMemoryBoundsIndicadorMorph new.
	stringMorph memoryProbe: memoryProbe.
	window 
		addMorph: (stringMorph)
		fullFrame: (LayoutFrame fractions: (0 @ 0.8 corner: 1 @ 1) offsets: (0 @ 0 corner: 0 @ 0)).

	window model: self.

	self initializeButtonsIn: window.
	window openInWorld.
	window extent: 400 @ 150.
	^ window! !

!MemoryMonitor methodsFor: 'configuration' stamp: 'Alexandre Bergel 5/25/2010 14:30'!
windowTitle
	^ 'Manuia Memory Monitor'! !

Object subclass: #MMProbe
	instanceVariableNames: 'values probe color highlightX tooltip toolTipPosition'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

MMProbe subclass: #MEndOfMemoryProbe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MEndOfMemoryProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/31/2010 15:35'!
color
	^ Color lightRed! !

!MEndOfMemoryProbe methodsFor: 'accessing' stamp: 'PhilippeBack 2/24/2013 17:23'!
currentEndOfMemory
	^ Smalltalk vm parameterAt: 3! !

!MEndOfMemoryProbe methodsFor: 'initialization' stamp: 'Alexandre Bergel 5/31/2010 15:35'!
initialize
	super initializeFor: #currentEndOfMemory! !

MMProbe subclass: #MFreeMemoryProbe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MFreeMemoryProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 18:41'!
color
	^ Color lightRed! !

!MFreeMemoryProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 18:37'!
currentFreeMemory
	| image memoryEnd youngSpaceEnd |
	image := SmalltalkImage current.
	memoryEnd			:= image vmParameterAt: 3.
	youngSpaceEnd		:= image vmParameterAt: 2.
	^ memoryEnd - youngSpaceEnd! !

!MFreeMemoryProbe methodsFor: 'initialization' stamp: 'Alexandre Bergel 5/25/2010 18:35'!
initialize
	super initializeFor: #currentFreeMemory! !

MMProbe subclass: #MInstancesProbe
	instanceVariableNames: 'classToBeProbed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MInstancesProbe class methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 6/4/2010 22:11'!
forClassNamed: className
	 ^ (self  
		probeBlock: [:probe | (Smalltalk at: className asSymbol) instanceCount])
		classToBeProbed: (Smalltalk at: className asSymbol)! !

!MInstancesProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 6/4/2010 22:08'!
classToBeProbed
	^ classToBeProbed! !

!MInstancesProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 6/4/2010 22:08'!
classToBeProbed: aBehavior
	classToBeProbed := aBehavior.
	! !

!MInstancesProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 6/4/2010 22:12'!
writeToolTipTextOn: stream forIndex: index

	stream nextPutAll: (self valuesAt: index) printString, ' #', classToBeProbed name! !

MMProbe subclass: #MMGCProbe
	instanceVariableNames: 'oldValue'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MMGCProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/30/2010 21:36'!
color
	^ Color lightGray! !

!MMGCProbe methodsFor: 'accessing-readonly' stamp: 'PhilippeBack 2/24/2013 17:24'!
currentValue
	| v answer |

	v := Smalltalk vm parameterAt: 9.
	"return true or false"
	
	oldValue ifNil: [ oldValue := v. ^ false ].
	answer := v - oldValue > 10.
	oldValue := v.
	^ answer! !

!MMGCProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 5/27/2010 19:05'!
renderOnCanvas: aCanvas bounds: bounds
	| width origin height maxValue offset minValue diffExtremeValue diffExtremeValues step previousPoint newPoint oldPoint newPoint1 newPoint2 |
	origin := bounds origin.
	height := bounds height.
	width := bounds width.
	
	offset := 0 @ 0.
	step := (bounds width / self historyLength ).

	self values
		do: [ :v | 
			v ifTrue: [
				newPoint1 := origin + offset asIntegerPoint.
				newPoint2 := newPoint1 + (0 @ height).
				aCanvas line: newPoint1 to: newPoint2 color: self color ].
			offset := offset + (step @ 0) ]! !

!MMProbe class methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 5/31/2010 15:20'!
probeBlock: aSelectorOrBlock
	^ self new initializeFor: aSelectorOrBlock! !

!MMProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 18:27'!
addValue: v
	self shiftValues.
	self values at: self values size put: v! !

!MMProbe methodsFor: 'updating' stamp: 'Alexandre Bergel 5/25/2010 18:27'!
clear
	values := nil! !

!MMProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 20:22'!
color
	^ color! !

!MMProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 20:23'!
color: aColor
	color := aColor ! !

!MMProbe methodsFor: 'metrics' stamp: 'Alexandre Bergel 5/25/2010 18:25'!
computeMaxValue
	^ self values max! !

!MMProbe methodsFor: 'metrics' stamp: 'Alexandre Bergel 5/25/2010 18:25'!
computeMinValue
	^ self values min! !

!MMProbe methodsFor: 'accessing-readonly' stamp: 'Alexandre Bergel 5/25/2010 18:26'!
currentValue
	^ probe value: self! !

!MMProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 6/4/2010 20:42'!
highlight: position
	position ifNil: [ highlightX := nil. ^ self ].
	highlightX := position x.
! !

!MMProbe methodsFor: 'configuration' stamp: 'Alexandre Bergel 5/25/2010 18:22'!
historyLength
	^ 100! !

!MMProbe methodsFor: 'initialization' stamp: 'Alexandre Bergel 5/25/2010 20:22'!
initializeFor: aSelectorOrBlock
	| v |
	super initialize.
	color := Color green.
	probe := aSelectorOrBlock.
	values := Array new: self historyLength.
	v := self currentValue.
	1 to: values size do: [ :i | values at: i put: v ]! !

!MMProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 6/4/2010 20:41'!
renderOnCanvas: aCanvas bounds: bounds
	| width origin height maxValue offset minValue diffExtremeValue diffExtremeValues step previousPoint newPoint oldPoint |
	origin := bounds origin.
	height := bounds height.
	width := bounds width.
	maxValue := self computeMaxValue.
	minValue := self computeMinValue.
	diffExtremeValues := maxValue - minValue.
	diffExtremeValues = 0 ifTrue: [ diffExtremeValues := 1 ].
	offset := 0 @ 0.
	step := (bounds width / self historyLength ).
	previousPoint := nil.
	self values
		do: [ :v | 
			maxValue = 0
				ifTrue: [ maxValue := 1 ].
				
			newPoint := origin + offset asIntegerPoint + (0 @ (height) - 1) - (0@((v - minValue) * height / diffExtremeValues) asInteger).
			oldPoint ifNotNil: [ aCanvas line: oldPoint to: newPoint color: self color ].

			(highlightX notNil and: [((newPoint x <= (highlightX + origin x)) 
									and: [ (highlightX + origin x) < (newPoint x + step) ] )])
				ifTrue: [  aCanvas line: (newPoint - (-2 @ -2)) to:  (newPoint - (2 @ -2)) color: self color.
						  aCanvas line: (newPoint - (-2 @ -1)) to:  (newPoint - (2 @ -1)) color: self color.
						  aCanvas line: (newPoint - (-2 @ 0)) to:  (newPoint - (2 @ 0)) color: self color.
						aCanvas line: (newPoint - (-2 @ 1)) to:  (newPoint - (2 @ 1)) color: self color.
						aCanvas line: (newPoint - (-2 @ 2)) to:  (newPoint - (2 @ 2)) color: self color   ].

			oldPoint := newPoint.
			offset := offset + (step @ 0) ]! !

!MMProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 5/25/2010 18:28'!
shiftValues
	2 to: self values size do: [ :i | self values at: i - 1 put: (self values at: i) ].
	self values at: (self values size) put: 0! !

!MMProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 5/25/2010 18:29'!
updateValue
	self addValue: self currentValue! !

!MMProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 5/25/2010 18:29'!
values 
	| v |
	values ifNotNil: [ ^ values ].
	values := Array new: (self historyLength).
	v := self currentValue.
	1 to: self historyLength do: [ :i | values at: i put: v].
	
	^ values! !

!MMProbe methodsFor: 'accessing-readonly' stamp: 'Alexandre Bergel 6/4/2010 21:57'!
valuesAt: index 
	^ self values at: index! !

!MMProbe methodsFor: 'accessing-readonly' stamp: 'Alexandre Bergel 6/4/2010 21:59'!
valuesAtX: x
	((0 to: self bounds width) includes: x) ifFalse: [ ^ nil ].
	^ self values at: (x * self values size / self bounds width)! !

!MMProbe methodsFor: 'actions' stamp: 'Alexandre Bergel 6/4/2010 22:03'!
writeToolTipTextOn: stream forIndex: index

	stream nextPutAll: (self valuesAt: index) printString! !

MMProbe subclass: #MUsedMemoryProbe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MemoryMonitor'!

!MUsedMemoryProbe methodsFor: 'accessing' stamp: 'PhilippeBack 2/24/2013 17:23'!
currentUsedMemory
	^ Smalltalk vm parameterAt: 2
	! !

!MUsedMemoryProbe methodsFor: 'initialization' stamp: 'Alexandre Bergel 5/25/2010 18:35'!
initialize
	super initializeFor: #currentUsedMemory! !

!MUsedMemoryProbe methodsFor: 'accessing' stamp: 'Alexandre Bergel 6/4/2010 22:06'!
writeToolTipTextOn: stream forIndex: index
	| v |
	v := self valuesAt: index.
	stream nextPutAll: (((v / (1024 * 1024)) asFloat roundTo: 0.1) asString , 'M')! !
